@@ -173,7 +173,7 @@ GtkWidget* create_tea_main_window (void)
 
 //#ifdef HACKING_MODE
   //mni_temp = new_menu_item ("test", mni_file_menu, on_mni_test);
- // mni_temp = new_menu_item (_("test24"), mni_file_menu, on_mni_test2);
+ // mni_temp = new_menu_item ("test24", mni_file_menu, on_mni_test2);
 //#endif
 
 
@@ -426,6 +426,10 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("Document weight"), mni_html_menu, on_mni_html_calc_weight);
   mni_temp = new_menu_item (_("Text to HTML"), mni_html_menu, on_mni_text_to_html_fmt);
 
+#ifdef LIBCURL_SUPPORTED
+  mni_temp = new_menu_item (_("Check for broken links"), mni_html_menu, on_mni_check_links);
+#endif
+
   mni_temp = new_menu_sep (mni_markup_menu);
 
   mni_bold = new_menu_item (_("Bold"), mni_markup_menu, on_mni_Markup_bold_activate);
@@ -901,6 +905,9 @@ GtkWidget* create_tea_main_window (void)
   gtk_box_pack_start (GTK_BOX (statusbar1), pb_status, FALSE, FALSE, UI_PACKFACTOR);
   gtk_progress_bar_set_pulse_step (pb_status, 0.05);
 
+
+ // gtk_progress_bar_set_ellipsize (pb_status, PANGO_ELLIPSIZE_END);
+
   g_signal_connect ((gpointer) notebook1, "switch_page",
                     G_CALLBACK (on_notebook1_switch_page),
                     NULL);
@@ -938,7 +945,7 @@ GtkWidget* create_tea_main_window (void)
 
   log_to_memo (_("PLEASE read the manual :)"), NULL, LM_GREET);
   log_to_memo ("<peter.semiletov@gmail.com>", NULL, LM_GREET);
-  log_to_memo ("(C)2000-2007 Peter Semiletov", NULL, LM_GREET);
+  log_to_memo ("(C)2000-2008 Peter Semiletov", NULL, LM_GREET);
 
   gchar* teavers;
 
