@@ -2,7 +2,7 @@
                           interface.h  -  description
                              -------------------
     begin                : Mon Dec 1 2003
-    copyright            : (C) 2003-2006 by Peter 'Roxton' Semiletov
+    copyright            : (C) 2003-2007 by Peter 'Roxton' Semiletov
     email                : peter.semiletov@gmail.com
  ***************************************************************************/
 
@@ -18,6 +18,13 @@ GtkNotebook *notebook1;
 GtkWidget *menubar1;
 GtkWidget *mni_file_menu;
 GtkWidget *mni_mark_menu;
+GtkWidget *mni_print;
+GtkWidget *mni_reptables_menu;
+GtkWidget *mni_reptables;
+
+GtkWidget *mni_profiles_menu;
+GtkWidget *mni_profiles;
+
 
 GtkWidget *mni_file_configs_menu;
 GtkWidget *mni_autocomp;
@@ -121,6 +128,43 @@ GtkWidget *mni_scripts;
 
 GtkWidget *mni_scripts_menu;
 
+GtkWidget *mni_file_new;
+GtkWidget *mni_file_kwas;
+GtkWidget *mni_file_crapbook;
+GtkWidget *mni_file_open;
+GtkWidget *mni_file_save;
+GtkWidget *mni_file_save_ver;
+GtkWidget *mni_file_save_backup;
+GtkWidget *mni_file_close_current;
+GtkWidget *mni_file_quit;
+GtkWidget *mni_edit_line_up;
+GtkWidget *mni_edit_line_down;
+GtkWidget *mni_edit_delete_cur_line;
+GtkWidget *mni_find_now;
+GtkWidget *mni_find_now_caseinsens;
+GtkWidget *mni_find_next;
+GtkWidget *mni_find_next_caseinsens;
+GtkWidget *mni_goto_line;
+
+GtkWidget *mni_bold;
+GtkWidget *mni_italic;
+GtkWidget *mni_comment;
+GtkWidget *mni_para;
+GtkWidget *mni_br;
+GtkWidget *mni_nbp;
+GtkWidget *mni_link;
+GtkWidget *mni_color;
+GtkWidget *mni_align_center;
+GtkWidget *mni_stats;
+GtkWidget *mni_upcase;
+GtkWidget *mni_locase;
+GtkWidget *mni_apply_tpl_to_each_ln;
+GtkWidget *mni_block_start;
+GtkWidget *mni_block_end;
+GtkWidget *mni_open_at_cursor;
+GtkWidget *mni_refresh_hl;
+GtkWidget *mni_word_wrap;
+
 
 GtkWidget *statusbar1;
 GtkAccelGroup *accel_group;
