@@ -1313,6 +1313,7 @@ gint get_gchar_array_size (const gchar **a)
 }
 
 
+
 gchar* morse_encode (const gchar *s)
 {
   if (! s)
@@ -1466,8 +1467,6 @@ gchar* morse_decode (const gchar *s)
   g_hash_table_insert (ht, "-..-.", "/");
   g_hash_table_insert (ht, "-....-", "-");
   g_hash_table_insert (ht, ".----.", "'");
-  g_hash_table_insert (ht, "-.--.-", ")");
-  g_hash_table_insert (ht, "---", "(");
   g_hash_table_insert (ht, "..--.-", "_");
   g_hash_table_insert (ht, "-..-.", "/");
   g_hash_table_insert (ht, ".-.-.", "+");
@@ -1495,7 +1494,7 @@ gchar* morse_decode (const gchar *s)
   g_string_free (gs, FALSE);
   g_hash_table_destroy (ht);
   g_strfreev (a);
-  //.-. .- -.. .. --- .- -.-. - .. ...- .. - -..--
+  //.-. .- -.. .. --- .- -.-. - .. ...- .. - -.--
   return p;
 }
 
@@ -2320,7 +2319,7 @@ gchar* text_load_msdoc (const gchar *filename)
   if (! filename)
      return NULL;
 
-  gchar *cm = g_strconcat ("antiword -m UTF-8.txt ", filename, " > ", confile.tmp_file, NULL);
+  gchar *cm = g_strconcat ("antiword -m UTF-8.txt \"", filename, "\" > ", confile.tmp_file, NULL);
   system (cm);
   g_free (cm);
   return get_tmp_file_string ();
