@@ -6,8 +6,6 @@
     email                : peter.semiletov@gmail.com
  ***************************************************************************/
 /*
- *some code from  Osmo - a handy personal organizer
- *
  * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
 */
 
@@ -44,69 +42,6 @@
 #include "tea_calendar.h"
 
 
-/*
-some functions from Osmo
- * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
-
-*/
-
-
-
-gboolean
-is_leap_year(gint year) {
-
-    if ((year % 100) == 0)
-        return (year % 400) == 0 ? TRUE : FALSE;
-
-    return (year % 4) == 0 ? TRUE : FALSE;
-}
-
-/*------------------------------------------------------------------------------*/
-/* This routine has been taken from http://www.voidware.com/moon_phase.htm */
-
-gint
-calc_moon_phase(gint myear, gint mmonth, gint mday) {
-
-/*
-      calculates the moon phase (0-7), accurate to 1 segment.
-      0 = > new moon.
-      4 => full moon.
-*/
-
-gint b, c, e;
-gdouble jd;
-
-    if (mmonth < 3) {
-        myear--;
-        mmonth += 12;
-    }
-    ++mmonth;
-    c = 365.25*myear;
-    e = 30.6*mmonth;
-    jd = c+e+mday-694039.09; /* jd is total days elapsed */
-    jd /= 29.53;             /* divide by the moon cycle (29.53 days) */
-    b = jd;                  /* int(jd) -> b, take integer part of jd */
-    jd -= b;                     /* subtract integer part to leave fractional part of original jd */
-    b = jd*8 + 0.5;              /* scale fraction from 0-8 and round by adding 0.5 */
-    b = b & 7;                   /* 0 and 8 are the same so turn 8 into 0 */
-
-    return b;
-}
-
-/*------------------------------------------------------------------------------*/
-
-gchar*
-get_moon_phase_name(gint phase) {
-
-const gchar *phase_names[] = {
-    N_("New Moon"), N_("Waxing Crescent Moon"), N_("Quarter Moon"), N_("Waxing Gibbous Moon"),
-    N_("Full Moon"), N_("Waning Gibbous Moon"), N_("Last Quarter Moon"), N_("Waning Crescent Moon")
-};
-
-    return (gchar *)gettext(phase_names[phase]);
-}
-
-
 
 static GDate *date1;
 static GDate *date2;
