@@ -113,20 +113,26 @@ void ui_init (void)
   gl_tea_kwas_bookmarks = load_file_to_glist (confile.tea_kwas_bookmarks);
 
 
-  confile.def_spell_lang = conf_get_char_value (ui, "def_spell_lang", "en");
+  gchar *localeid = get_lang_name ();
+  confile.def_spell_lang = conf_get_char_value (ui, "def_spell_lang", localeid);
+  g_free (localeid);
+
   confile.last_version = conf_get_char_value (ui, "last_version", "xxxxxx");
   confile.last_prefs_tab = conf_get_int_value (ui, "last_prefs_tab", 0);
   confile.filter_index = conf_get_int_value (ui, "filter_index", 0);
 
-  gtk_paned_set_position (vpaned1, conf_get_int_value (ui, "vpaned1_y", 300));
+  gint main_wnd_w = conf_get_int_value (ui, "main_wnd_w", 630);
+  gint main_wnd_h = conf_get_int_value (ui, "main_wnd_h", 450);
+
+  gtk_paned_set_position (vpaned1, conf_get_int_value (ui, "vpaned1_y", get_value (main_wnd_h, 70)));
 
   gtk_window_move (GTK_WINDOW (tea_main_window),
                    conf_get_int_value (ui, "main_wnd_x", 2),
                    conf_get_int_value (ui, "main_wnd_y", 2));
 
-  gtk_window_resize (GTK_WINDOW (tea_main_window),
-                     conf_get_int_value (ui, "main_wnd_w", 630),
-                     conf_get_int_value (ui, "main_wnd_h", 450));
+  gtk_window_resize (GTK_WINDOW (tea_main_window), main_wnd_w, main_wnd_h);
+
+  gtk_widget_set_size_request (pb_status, get_value (main_wnd_w, 60), -1);
 
   confile.default_markup_mode = conf_get_char_value (ui, "default_markup_mode", "HTML");
   def_mm = get_markup_mode ();
@@ -1025,6 +1031,7 @@ void confile_reload (void)
   confile.homeend = ht_get_int_value ("homeend", 0);
 
   confile.start_with_blank_file = ht_get_int_value ("start_with_blank_file", 0);
+  confile.fte_autocomp = ht_get_int_value ("fte_autocomp", 1);
 
   confile.do_last_session = ht_get_int_value ("do_last_session", 0);
   confile.do_autosave_session = ht_get_int_value ("do_autosave_session", 0);
@@ -1088,7 +1095,7 @@ void confile_reload (void)
 
   //n.p. Scorn - Orgy Of Holyness
 
-  confile.cmd_def_doc_browser = ht_get_char_value ("def_doc_browser", "mozilla %s&");
+  confile.cmd_def_doc_browser = ht_get_char_value ("def_doc_browser", "firefox %s&");
   confile.use_def_doc_browser = ht_get_int_value ("use_def_doc_browser", 0);
 
   confile.allow_multiple_instances = ht_get_int_value ("allow_multiple_instances", 0);
@@ -1114,7 +1121,6 @@ void confile_reload (void)
 
   confile.main_wnd_show_full_path = ht_get_int_value ("main_wnd_show_full_path", 1);
   confile.do_backup = ht_get_int_value ("do_backup", 0);
-//  confile.do_hl_on_fileopen = ht_get_int_value ("do_hl_on_fileopen", 1);
   confile.show_hidden_files = ht_get_int_value ("show_hidden_files", 1);
   confile.implane_ins_image = ht_get_int_value ("implane_ins_image", 0);
 
@@ -1150,8 +1156,7 @@ void confile_reload (void)
   confile.enc_det_turkish = ht_get_int_value ("enc_det_turkish", 0);
 
   confile.scan_for_links_on_doc_open = ht_get_int_value ("scan_for_links_on_doc_open", 0);
-  confile.logmemo_lines_max = ht_get_int_value ("logmemo_lines_max", 13);
-//  confile.fam_autocomp_lines_max = ht_get_int_value ("fam_autocomp_lines_max", 1024);
+  confile.logmemo_lines_max = ht_get_int_value ("logmemo_lines_max", 777);
   confile.fte_min_prefix_len = ht_get_int_value ("fte_min_prefix_len", 3);
 
   g_hash_table_destroy (ht_config);
