@@ -19,7 +19,6 @@
 #  include <config.h>
 #endif
 
-
 /*
  * Standard gettext macros.
  */
@@ -47,6 +46,7 @@
 
 #define eol_LF 0
 #define eol_CRLF 1
+#define eol_CR 2
 
 #define CHAI_BASE_KEY "/apps/chai"
 #define CHAI_PREFS_DIR CHAI_BASE_KEY "/preferences"
@@ -116,7 +116,7 @@
 
 #else
 
-#if defined(DARWIN)
+#if defined(DARWIN) || defined(OpenBSD)
 
 #define TEA_DOC_DIR PACKAGE_DATA_DIR"/doc/tea/"
 
@@ -126,6 +126,7 @@
 
 #endif
 
+
 #define TEA_PIX_MAINLOGO PACKAGE_DATA_DIR"/tea/pixmaps/tea_logo.jpg"
 #define TEA_PIX_MAINICON PACKAGE_DATA_DIR"/tea/pixmaps/tea_icon_v2.png"
 #define TEA_PIX_DIR PACKAGE_DATA_DIR"/tea/pixmaps/"
@@ -141,4 +142,10 @@
 #define DSK_GNOME 2
 #define DSK_XFCE 3
 
+#define DCM_NONE 0
+#define DCM_GREP 1
+#define DCM_MAKE 2
+#define DCM_LATEX 3
+
+#define combo_get_value(combo,list) g_list_nth_data (list,gtk_combo_box_get_active(combo))
 
