@@ -103,6 +103,7 @@ static gint button_press_event (GtkWidget *widget, GdkEventButton *event, gpoint
              gchar *l = get_l_filename (s);
              execute_recent_item (l);
              g_free (l);
+             g_free (s);
              return TRUE;
             }
          }
@@ -118,8 +119,8 @@ static GList* find_in_files (t_find_in_files_mult *instance, GList *files)
   GList *result = NULL;
 
   GList *l = g_list_first (files);
-//  gchar *enc = gtk_combo_box_get_active_text (instance->cmb_charset); //2.6
-  gchar *enc = g_strdup (g_list_nth_data (confile.gl_save_charsets, gtk_combo_box_get_active (instance->cmb_charset)));
+
+  gchar *enc = g_strdup (combo_get_value (instance->cmb_charset, confile.gl_save_charsets));
 
   gchar *text_to_find = gtk_entry_get_text (instance->ent_text_to_find);
 
@@ -272,6 +273,7 @@ static void on_button_copy_filename (GtkWidget *wid, gpointer data)
   gchar **a = g_strsplit (line, ",", -1);
   clipboard_put_text (a[0]);
   g_strfreev (a);
+  g_free (line);
 }
 
 
@@ -279,13 +281,9 @@ static void on_button_list_clear (GtkWidget *wid, gpointer data)
 {
   t_find_in_files_mult *instance = data;
   tv_clear (instance->tv_found_files);
-//  gchar *line = tv_get_selected_single (instance->tv_found_files);
- // gchar **a = g_strsplit (line, ",", -1);
- // clipboard_put_text (a[0]);
 }
 
 
-
 GtkWidget* create_findfiles_mult (void)
 {
   GtkWidget *frame_and_strings;
