@@ -311,7 +311,7 @@ gboolean check_ext (const gchar *filename, const gchar *ext)
 
 gboolean is_markup (const gchar *f)
 {
-  return is_ext (f, ".html", ".htm", ".xml", ".xhtml", ".sgm", ".shtml", ".sgml", ".docbook", NULL);
+  return is_ext (f, ".html", ".htm", ".xml", ".xhtml", ".sgm", ".shtml", ".sgml", ".docbook", ".ts", NULL);
 }
 
 
