@@ -574,7 +574,9 @@ void fill_combo_with_glist (GtkComboBox *combo, GList *l)
   while (t && t->data)
         {
          //if (strlen (t->data) > 1)
-            gtk_combo_box_append_text (combo, t->data);
+         //gtk_combo_box_prepend_text (combo, t->data);
+         gtk_combo_box_append_text (combo, t->data);
+
          t = g_list_next (t);
         }
 }
@@ -793,3 +795,42 @@ GtkWidget* tea_text_entry_hotkey (GtkWidget *container, const gchar *caption, co
 
   return x;
 }
+
+
+static void on_bt_choose (GtkButton *button,
+                          gpointer user_data)
+{
+  gchar *x = request_item_from_tvlist (user_data);
+
+  if (x)
+     {
+      gtk_button_set_label (button, x);
+      g_free (x);
+     }
+}
+
+
+GtkWidget* tea_button_list_items (
+                                  GtkWidget *container,
+                                  GList *list,
+                                  const gchar *caption,
+                                  const gchar *defval
+                                  )
+{
+  GtkWidget *b = gtk_hbox_new (FALSE, UI_PACKFACTOR);
+  gtk_widget_show (b);
+  gtk_box_pack_start (container, b, FALSE, TRUE, UI_PACKFACTOR);
+
+  GtkWidget *x = gtk_label_new (caption);
+  gtk_widget_show (x);
+  gtk_box_pack_start (b, x, FALSE, FALSE, UI_PACKFACTOR);
+
+  GtkWidget *bt = gtk_button_new_with_label (defval);
+  gtk_widget_show (bt);
+
+  gtk_box_pack_start (b, bt, FALSE, FALSE, UI_PACKFACTOR);
+
+  g_signal_connect (bt, "clicked", G_CALLBACK (on_bt_choose), list);
+
+  return bt;
+}
