@@ -14,7 +14,6 @@ GtkWidget* tea_button_at_box (GtkWidget *container, const gchar *caption, gpoint
 void cb_on_bt_close (GtkObject *object, GtkWidget *w);
 GtkWidget* find_menuitem (GtkContainer *widget, const gchar *widget_name);
 GtkFileFilter* tea_file_filter_with_patterns (const gchar *name, gchar *pattern1, ...);
-GtkFileFilter* find_ffilter_by_name (GtkFileChooser *chooser, const gchar *name);
 GtkWidget* daisho_add_del (gpointer *f1, gpointer f2);
 GtkWidget* new_menu_item_with_udata (const gchar *label, GtkWidget *parent, gpointer f, gpointer data);
 GtkWidget* new_menu_sep (GtkWidget *parent);
@@ -23,19 +22,14 @@ GtkWidget* new_menu_tof (GtkWidget *parent);
 GtkWidget* new_menu_submenu (GtkWidget *parent);
 void window_destroy (GtkWidget *windowname);
 gboolean win_key_handler (GtkWidget *widget, GdkEventKey *event, GtkWidget *w);
-GtkWidget* new_action_item (GtkActionGroup *ag,
-                            GtkWidget *parent,
-                            const gchar *name,
-                            const gchar *label,
-                            const gchar *tooltip,
-                            const gchar *stock_id,
-                            gpointer f);
 void set_cursor_blink (gboolean value);
 void fill_combo_with_glist (GtkComboBox *combo, GList *l);
 GtkWidget* tea_gtk_toolbar_prepend_space (GtkToolbar *toolbar);
 GtkWidget* tea_font_button (GtkWidget *container, const gchar *caption, const gchar *value);
 GtkWidget* tea_stock_button (const gchar *stock_id);
-GtkWidget* tea_combo_combo (GtkWidget *container, GList *strings, const gchar *caption, gint value);
+GtkWidget* tea_combo_combo (GtkWidget *container, GList *strings, const gchar *caption, gint value,
+gpointer on_changed, gpointer user_data);
+
 gchar* dlg_question_char (const gchar *prompt, const gchar *defval);
 gboolean dlg_key_handler (GtkWidget *widget, GdkEventKey *event, GtkWidget *w);
 void build_menu_from_ht (GHashTable *hash_table, gpointer menu, gpointer callback);
@@ -43,6 +37,12 @@ void build_menu_from_glist (GList *list, gpointer menu, gpointer callback);
 void build_menu_wudata_from_glist (GList *list, gpointer menu, gpointer callback, gpointer udata);
 void tea_widget_show (GtkWidget *w, gboolean visible);
 GtkWidget* tea_color_selector_simple (GtkWidget *container, const gchar *caption);
-gchar* get_gtk_ver (void);
-//GtkWidget* tea_dir_selector2 (GtkWidget *container, const gchar *caption, const gchar *value);
 gchar* get_text_buf (gpointer text_buffer);
+GtkWidget* tea_shortcut_entry (void);
+GtkWidget* tea_text_entry_hotkey (GtkWidget *container, const gchar *caption, const gchar *value);
+GtkWidget* tea_button_list_items (
+                                  GtkWidget *container,
+                                  GList *list,
+                                  const gchar *caption,
+                                  const gchar *defval
+                                  );
