@@ -8,12 +8,16 @@ GList *gl_tags_list;
 GtkCheckButton *cb_margin_visible;
 GtkSpinButton *sb_margin_width;
 
+GtkSpinButton *sb_fte_min_prefix_len;
+
+GtkSpinButton *sb_jpeg_q;
+GtkSpinButton *sb_screenshot_delay;
 
 GtkColorButton *bt_tag_background;
 GtkColorButton *bt_tag_foreground;
 
 GtkCheckButton *cb_homeend;
-
+GtkCheckButton *cb_automatic_markup_mode;
 
 GtkCheckButton *cb_hl_italic;
 GtkCheckButton *cb_hl_bold;
@@ -22,6 +26,15 @@ GtkCheckButton *cb_hl_strikethrough;
 
 GtkTreeView *tv_available_hlangs;
 GtkTreeView *tv_hlang_elements;
+GtkTreeView *tv_menuitems;
+
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+
+GtkWidget *cbm_color_cheme;
+
+#endif
+
+GtkEntry *ent_shortcut;
 
 
 GtkEntry *ent_def_save_dir;
@@ -43,6 +56,9 @@ GtkEntry *ent_cm_manual_browser;
 
 GtkEntry *ent_cm_mplayer;
 
+GtkEntry *ent_cm_pack;
+
+
 GtkEntry *ent_tag_color_lm_error_fg;
 GtkEntry *ent_tag_color_lm_error_bg;
 
@@ -61,43 +77,32 @@ GtkEntry *ent_text_background;
 GtkEntry *ent_text_sel_foreground;
 GtkEntry *ent_text_sel_background;
 
-
-
 GtkCheckButton *cb_add_def_file_ext;
 GtkEntry *ent_def_file_ext;
 
 
+GtkCheckButton *cb_exclusive_enter_at_dialogs;
 GtkCheckButton *cb_autorestore_last_session;
-
 GtkCheckButton *cb_det_charset_by_meta;
-
 GtkCheckButton *cb_do_save_all_on_termination;
 GtkCheckButton *cb_do_crash_file;
-
 GtkCheckButton *cb_common_closing_button_visible;
-
-
 GtkCheckButton *cb_hl_current_line;
 GtkCheckButton *cb_use_autocomp;
 GtkCheckButton *cb_autoclose_tags;
 GtkCheckButton *cb_implane_ins_image;
 GtkCheckButton * cb_use_cursor_blink;
-
 GtkCheckButton *cb_use_snippets;
 GtkCheckButton *cb_use_ext_image_viewer;
-GtkCheckButton *cb_do_hl_on_fileopen;
+//GtkCheckButton *cb_do_hl_on_fileopen;
 GtkCheckButton *cb_do_backup;
 GtkCheckButton *cb_ins_spaces_on_tab_press;
 GtkCheckButton *cb_do_autorep;
 GtkCheckButton *cb_do_show_main_toolbar;
-
 GtkCheckButton *cb_prompt_on_not_saved;
 GtkCheckButton *cb_prompt_on_file_exists;
-
 GtkCheckButton *cb_use_def_doc_browser;
-
 GtkCheckButton *cb_do_det_scripts_by_content;
-
 GtkCheckButton *cb_show_hidden_files;
 GtkCheckButton *cb_show_line_nums;
 GtkCheckButton *cb_word_wrap;
@@ -105,29 +110,25 @@ GtkCheckButton *cb_use_autocomp;
 GtkCheckButton *cb_use_def_save_dir;
 GtkCheckButton *cb_use_def_open_dir;
 GtkCheckButton *cb_use_auto_indent;
-
-
 GtkCheckButton *cb_fullscreen;
 GtkCheckButton *cb_do_autosave;
-
+GtkCheckButton *cb_do_autosave_session;
 GtkCheckButton *cb_show_cursor_pos;
-
 GtkCheckButton *cb_scan_for_links_on_doc_open;
-
 GtkCheckButton *cb_main_wnd_show_full_path;
 GtkCheckButton *cb_start_with_blank_file;
-//GtkCheckButton *cb_start_with_recent_file;
-
 
 GtkWidget *sb_logmemo_lines_max;
 GtkWidget *sb_famous_history_max;
 GtkWidget *sb_max_recent_items;
 GtkWidget *sb_autosave_interval;
 
+//GtkWidget *sb_fam_autocomp_lines_max;
+//GtkWidget *sb_fam_min_prefix_len;
+
+
 
 GtkWidget *sb_max_undo_levels;
-
-
 GtkWidget *sb_autocomp_wordlen_min;
 GtkWidget *sb_autocomp_list_items_max;
 
@@ -141,6 +142,8 @@ GtkWidget *sb_saveopen_h;
 GtkWidget *sb_tab_size;
 
 GtkEntry *ent_date_time;
+GtkEntry *ent_date_time_ver;
+
 GtkEntry *ent_now_playing;
 
 GtkEntry *ent_color_cursor;
@@ -153,16 +156,6 @@ GtkEntry *ent_tag_color_paint_fg;
 GtkEntry *ent_tag_color_paint_bg;
 
 
-/*
-GtkEntry *ent_tag_comment_font;
-GtkEntry *ent_tag_identifier_font;
-GtkEntry *ent_tag_digit_font;
-GtkEntry *ent_tag_string_font;
-GtkEntry *ent_tag_html_tag_font;
-GtkEntry *ent_tag_preprocessor_font;
-GtkEntry *ent_tag_type_font;
-GtkEntry *ent_editor_font;
-*/
 GtkFontButton *fb_tag_comment_font;
 GtkFontButton *fb_tag_identifier_font;
 GtkFontButton *fb_tag_digit_font;
@@ -200,9 +193,15 @@ GtkCheckButton *cb_enc_det_slovenian;
 GtkCheckButton *cb_enc_det_spanish;
 GtkCheckButton *cb_enc_det_turkish;
 
-GtkEntry *ent_rtf_enc;
-GtkEntry *ent_default_charset;
-GtkEntry *ent_def_filesave_charset;
+GtkCheckButton *cb_enc_use_fallback;
+
+GtkWidget *bt_rtf_enc;
+GtkWidget *bt_fallback_charset;
+
+GtkWidget *bt_default_charset;
+GtkWidget *bt_def_filesave_charset;
+
+
 GtkEntry *ent_def_markup_mode;
 
 GtkWidget* create_wnd_about (void);
@@ -212,3 +211,4 @@ GtkTreeView *tv_choosed_charsets;
 GtkTreeView *tv_notetab_positions;
 
 GtkWidget* wnd_options_create (void);
+GtkWidget* lookup_widget3 (GtkContainer *widget, const gchar *widget_name);
